https://gcc.gnu.org/g:18dc571dfa903de5e5b868157d653fbf5a06c0e3

commit r17-1098-g18dc571dfa903de5e5b868157d653fbf5a06c0e3
Author: Dhruv Chawla <[email protected]>
Date:   Tue May 19 12:56:17 2026 +0000

    bpf: Fix typos in various files
    
    Signed-off-by: Dhruv Chawla <[email protected]>
    
    gcc/ChangeLog:
    
            * config/bpf/bpf.cc (bpf_asm_named_section): Fix typos.
            * config/bpf/core-builtins.cc (remove_parser_plugin): Likewise.
            (make_core_relo): Likewise.
            (bpf_handle_plugin_finish_type): Likewise.
            (bpf_output_core_reloc): Likewise.
            (core_make_builtins): Likewise.

Diff:
---
 gcc/config/bpf/bpf.cc           |  2 +-
 gcc/config/bpf/core-builtins.cc | 12 ++++++------
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/gcc/config/bpf/bpf.cc b/gcc/config/bpf/bpf.cc
index 4773d789d8e3..89a4917cd0a0 100644
--- a/gcc/config/bpf/bpf.cc
+++ b/gcc/config/bpf/bpf.cc
@@ -1245,7 +1245,7 @@ bpf_asm_named_section (const char *name, unsigned int 
flags,
      characters.  This includes for example names like /foo//bar/baz.
      This makes it necessary to quote section names to make sure the
      assembler doesn't get confused.  For example, the example above
-     would be interpreted unqouted as a section name "/foo" followed
+     would be interpreted unquoted as a section name "/foo" followed
      by a line comment "//bar/baz".
 
      Note that we only quote the section name if it contains any
diff --git a/gcc/config/bpf/core-builtins.cc b/gcc/config/bpf/core-builtins.cc
index d0c6cfdaf1c0..a5c973cd3856 100644
--- a/gcc/config/bpf/core-builtins.cc
+++ b/gcc/config/bpf/core-builtins.cc
@@ -264,7 +264,7 @@ remove_parser_plugin ()
 
 /* Helper compare functions used to verify if multiple builtin calls contain
    the same argument as input.  In that case the builtin calls can be optimized
-   out by identifying redundat calls.  This happen since the internal
+   out by identifying redundant calls.  This happen since the internal
    __core_reloc builtin is marked as PURE.  */
 
 static inline bool
@@ -1063,13 +1063,13 @@ bpf_require_core_support ()
 
 /* BPF Compile Once - Run Everywhere (CO-RE) support.  Construct a CO-RE
    relocation record in DATA to be emitted in the .BTF.ext
-   section.  Does nothing if we are not targetting BPF CO-RE, or if the
+   section.  Does nothing if we are not targeting BPF CO-RE, or if the
    constructed relocation would be a no-op.  */
 
 static void
 make_core_relo (struct cr_final *data, rtx_code_label *label)
 {
   /* If we are not targetting BPF CO-RE, do not make a relocation.  We
      might not be generating any debug info at all.  */
   if (!bpf_require_core_support ())
     return;
@@ -1207,7 +1207,7 @@ bpf_handle_plugin_finish_type (void *event_data,
 
 /* Initializes support information to process CO-RE builtins.
    Defines information for the builtin processing, such as helper functions to
-   support the builtin convertion.  */
+   support the builtin conversion.  */
 
 void
 bpf_init_core_builtins (void)
@@ -1660,7 +1660,7 @@ void
 bpf_output_core_reloc (rtx *operands, int nr_ops)
 {
   /* Search for an UNSPEC_CORE_RELOC within the operands of the emitting
-     intructions.  */
+     instructions.  */
   rtx unspec_exp = NULL_RTX;
   for (int i = 0; i < nr_ops; i++)
     {
@@ -1910,7 +1910,7 @@ core_make_builtins (tree *tp, int *walk_subtrees, void 
*data)
 
       tree new_expr = core_expr_with_field_expr_plus_base (base, expr, true);
 
       /* Abort convertion if it is just a pointer or a reference to an
         attributed type.  */
       if (new_expr != expr)
        {
@@ -1063,13 +1063,13 @@ bpf_require_core_support ()
 make_core_relo (struct cr_final *data, rtx_code_label *label)
 {
-  /* If we are not targetting BPF CO-RE, do not make a relocation.  We
+  /* If we are not targeting BPF CO-RE, do not make a relocation.  We
      might not be generating any debug info at all.  */
   if (!bpf_require_core_support ())
@@ -1910,7 +1910,7 @@ core_make_builtins (tree *tp, int *walk_subtrees, void 
       tree new_expr = core_expr_with_field_expr_plus_base (base, expr, true);
 
-      /* Abort convertion if it is just a pointer or a reference to an
+      /* Abort conversion if it is just a pointer or a reference to an
         attributed type.  */
       if (new_expr != expr)

Reply via email to